pub struct ValOpsFactory<I = i32, F = f64>{ /* private fields */ }Expand description
feature = "value" - Factory of default operators for the data type Val.
Operators available in addition to those from FloatOpsFactory are:
| representation | description |
|---|---|
% | reminder of integers |
| | bitwise or of integers |
& | bitwise and of integers |
XOR | bitwise exclusive or of integers |
<< | left shift of integers |
>> | right shift of integers |
|| | or for booleans |
&& | and for booleans |
if | returns first operand if second is true, else Val::None, to make x if condition else y possible |
else | returns second operand if first is Val::None, else first, to make x if condition else y possible |
==, !=, <, >, <=, >= | comparison operators between numbers, e.g., 1 == 1.0 is true. Comparing booleans to none-booleans is false, e.g., 1 == true is false. Comparisons with Val::None or Val::Error always results in false, e.g., (5 if false) == (5 if false) is false. |
fact | factorial of integers |
to_float | convert integer, float, or bool to float |
to_int | convert integer, float, or bool to integer |